Generate this documentation
===========================

.. generatedoc:

See `Generating the documention with pyquickhelper <http://www.xavierdupre.fr/app/pyquickhelper/helpsphinx/generatedoc.html>`_.

Configuration:

.. literalinclude:: conf.py

Extensions to install
+++++++++++++++++++++

* `pyquickhelper <https://pypi.python.org/pypi/pyquickhelper/>`_
* `sphinx_readable_theme <http://sphinx-readable-theme.readthedocs.org/en/latest/>`_
